==> jasperreports-server-cp-4.1.0-src.zip: jasperreports-server-cp-4.1.0-src/jasperserver/jasperserver-api-impl/engine/src/main/java/com/jaspersoft/jasperserver/api/engine/common/service/impl/GZipVirtualizerFactory.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.jaspersoft.jasperserver.api.engine.common.service.impl;

import net.sf.jasperreports.engine.JRVirtualizer;
import net.sf.jasperreports.engine.fill.JRGzipVirtualizer;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.jaspersoft.jasperserver.api.engine.common.service.VirtualizerFactory;

/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: GZipVirtualizerFactory.java 19922 2010-12-11 14:59:51Z tmatyashovsky $
 */
public class GZipVirtualizerFactory implements VirtualizerFactory {

	private static final Log log = LogFactory.getLog(GZipVirtualizerFactory.class);
	
	public static final int DEFAULT_MAX_SIZE = 200;
	
	private int maxSize;

	public GZipVirtualizerFactory() {
		// default values
		maxSize = DEFAULT_MAX_SIZE;
	}
	
	public JRVirtualizer getVirtualizer() {
		JRGzipVirtualizer virtualizer = new JRGzipVirtualizer(maxSize);
		
		if (log.isDebugEnabled()) {
			log.debug("Created GZip virtualizer " + virtualizer 
					+ " using " + maxSize + " as maxSize");
		}
		
		return virtualizer;
	}

	public void disposeVirtualizer(JRVirtualizer virtualizer) {
		if (virtualizer != null) {
			virtualizer.cleanup();
			
			if (log.isDebugEnabled()) {
				if (log.isDebugEnabled()) {
					log.debug("Disposed virtualizer " + virtualizer);
				}
			}
		}
	}
	
	public int getMaxSize() {
		return maxSize;
	}

	public void setMaxSize(int maxSize) {
		this.maxSize = maxSize;
	}

}

==> jasperreports-server-cp-5.1.0-src.zip: jasperreports-server-cp-5.1.0-src/jasperserver/jasperserver-api-impl/engine/src/main/java/com/jaspersoft/jasperserver/api/engine/common/service/impl/GZipVirtualizerFactory.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.jaspersoft.jasperserver.api.engine.common.service.impl;

import net.sf.jasperreports.engine.JRVirtualizer;
import net.sf.jasperreports.engine.fill.JRGzipVirtualizer;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: GZipVirtualizerFactory.java 30437 2013-03-28 17:54:52Z lchirita $
 */
public class GZipVirtualizerFactory extends AbstractIndividualVirtualizerFactory {

	private static final Log log = LogFactory.getLog(GZipVirtualizerFactory.class);
	
	public static final int DEFAULT_MAX_SIZE = 200;
	
	private int maxSize;

	public GZipVirtualizerFactory() {
		// default values
		maxSize = DEFAULT_MAX_SIZE;
	}
	
	public JRVirtualizer getVirtualizer() {
		JRGzipVirtualizer virtualizer = new JRGzipVirtualizer(maxSize);
		
		if (log.isDebugEnabled()) {
			log.debug("Created GZip virtualizer " + virtualizer 
					+ " using " + maxSize + " as maxSize");
		}
		
		return virtualizer;
	}
	
	public int getMaxSize() {
		return maxSize;
	}

	public void setMaxSize(int maxSize) {
		this.maxSize = maxSize;
	}

}
